# Pretty Verbose
[![PyPI version](https://img.shields.io/pypi/v/pyrly.svg)](https://pypi.org/project/pyrly/)
[![License](https://img.shields.io/pypi/l/pyrly.svg)](https://github.com/ccmorenos/pyrly/blob/main/LICENSE)
[![Test Python Package](https://github.com/ccmorenos/pyrly/actions/workflows/test-python.yml/badge.svg?branch=main)](https://github.com/ccmorenos/pyrly/actions/workflows/test-python.yml)
[![Upload Python Package](https://github.com/ccmorenos/pyrly/actions/workflows/python-publish.yml/badge.svg)](https://github.com/ccmorenos/pyrly/actions/workflows/python-publish.yml)

Package for administrating worked hours.

## Installation

The package is available in the [Python Package Index (PyPi)](https://pypi.org/project/pyrly/).

```bash
python3 -m pip install pyrly
```

## Usage

To use the admin run.

```shell
pyrly
```
